# Part of Odoo. See LICENSE file for full copyright and licensing details.

from . import test_currency
from . import test_currency_rate
from . import test_display_names
from . import test_locale
from . import test_session_info
